@@ -1,3 +1,5 @@
+#![allow(clippy::nonstandard_macro_braces)] // clippy bug, see https://github.com/rust-lang/rust-clippy/issues/7434
+
 // from: https://github.com/Maktm/FLIRTDB/blob/1f5763535e02d7cccf2f90a96a8ebaa36e9b2495/cmt/windows/libcmt_15_msvc_x86.pat#L355
 //
 //    3B0D........F27502F2C3F2E9...................................... 00 0000
@@ -25,7 +27,6 @@
 // ^0002 ___security_cookie
 // ^^^^^ reference offset
 // ^^^^^^^^^^^^^^^^^^ reference name
-
 use anyhow::Result;
 use log::trace;
 use nom::{
@@ -86,30 +87,27 @@ fn hex_word(input: &str) -> IResult<&str, u16> {
 fn hex_word_plus(input: &str) -> IResult<&str, u64> {
     let (input, nibbles) = take_while(is_hex_digit)(input)?;
     let mut v = 0u64;
-    let nibbles = nibbles
-        .chars()
-        .map(|c| match c {
-            '0' => 0,
-            '1' => 1,
-            '2' => 2,
-            '3' => 3,
-            '4' => 4,
-            '5' => 5,
-            '6' => 6,
-            '7' => 7,
-            '8' => 8,
-            '9' => 9,
-            'A' | 'a' => 0xA,
-            'B' | 'b' => 0xB,
-            'C' | 'c' => 0xC,
-            'D' | 'd' => 0xD,
-            'E' | 'e' => 0xE,
-            'F' | 'f' => 0xF,
-            _ => panic!("unexpect hex digit"),
-        })
-        .collect::<Vec<u8>>();
+    let nibbles = nibbles.chars().map(|c| match c {
+        '0' => 0,
+        '1' => 1,
+        '2' => 2,
+        '3' => 3,
+        '4' => 4,
+        '5' => 5,
+        '6' => 6,
+        '7' => 7,
+        '8' => 8,
+        '9' => 9,
+        'A' | 'a' => 0xA,
+        'B' | 'b' => 0xB,
+        'C' | 'c' => 0xC,
+        'D' | 'd' => 0xD,
+        'E' | 'e' => 0xE,
+        'F' | 'f' => 0xF,
+        _ => panic!("unexpect hex digit"),
+    });
 
-    for nibble in nibbles.into_iter() {
+    for nibble in nibbles {
         v <<= 4;
         v |= nibble as u64;
     }
