@@ -1,3 +1,5 @@
+#![allow(clippy::nonstandard_macro_braces)] // clippy bug, see https://github.com/rust-lang/rust-clippy/issues/7434
+
 use anyhow::Result;
 use log::trace;
 use nom::{
@@ -33,6 +35,7 @@ bitflags! {
     }
 }
 
+#[allow(dead_code)]
 #[derive(Debug)]
 enum HeaderExtra {
     V5,
@@ -61,6 +64,7 @@ impl HeaderExtra {
     }
 }
 
+#[allow(dead_code)]
 #[derive(Debug)]
 struct Header {
     // offset 6
